@@ -1,5 +1,6 @@
 use crate::{data::is_boundary, ObjectReader, Utf8Encoding, Windows1252Encoding};
 use crate::{Error, ErrorKind, Scalar};
+use std::fmt::Display;
 
 /// An operator token
 #[derive(Debug, PartialEq, Eq, Copy, Clone)]
@@ -17,6 +18,17 @@ pub enum Operator {
     GreaterThanEqual,
 }
 
+impl Display for Operator {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match *self {
+            Operator::LessThan => f.write_str("<"),
+            Operator::GreaterThan => f.write_str(">"),
+            Operator::LessThanEqual => f.write_str("<="),
+            Operator::GreaterThanEqual => f.write_str(">="),
+        }
+    }
+}
+
 /// Represents a valid text value
 #[derive(Debug, Clone, PartialEq)]
 pub enum TextToken<'a> {
@@ -1142,6 +1154,20 @@ mod tests {
         );
     }
 
+    #[test]
+    fn test_scalars_with_quoteas_delimiters() {
+        let data = br#""foo"="bar"3="1444.11.11""#;
+        assert_eq!(
+            parse(&data[..]).unwrap().token_tape,
+            vec![
+                TextToken::Quoted(Scalar::new(b"foo")),
+                TextToken::Quoted(Scalar::new(b"bar")),
+                TextToken::Unquoted(Scalar::new(b"3")),
+                TextToken::Quoted(Scalar::new(b"1444.11.11")),
+            ]
+        );
+    }
+
     #[test]
     fn test_escaped_quotes() {
         let data = br#"name = "Joe \"Captain\" Rogers""#;
